@@ -31,9 +31,15 @@ def get_sql_col_type(py_type):
 
 def make_stmt(sql_table, *filtering, **matching):
     """
-    Prepares SQL statement and returns it
+    Does select stmt
     """
     stmt = sa.select(sql_table)
+    return filter_stmt(stmt, sql_table, *filtering, **matching)
+
+def filter_stmt(stmt, sql_table, *filtering, **matching):
+    """
+    Prepares SQL statement and returns it
+    """
     if matching:
         for key, value in matching.items():
             stmt = stmt.where(getattr(sql_table.c, key) == value)
@@ -42,15 +48,25 @@ def make_stmt(sql_table, *filtering, **matching):
             stmt = stmt.where(item)
     return stmt
 
-def get_item(sql_table, engine, return_class, **filtering):
+def get_item(sql_table, engine, return_class, **matching):
     """
     Get item from table
     """
-    stmt = make_stmt(sql_table, **filtering)
+    stmt = make_stmt(sql_table, **matching)
     with engine.connect() as conn:
         cursor = conn.execute(stmt).first()
     return return_class(*cursor) if cursor else None
 
+def delete_item(sql_table, engine, **matching):
+    """
+    Executes delete stmt
+    """
+    stmt = sa.delete(sql_table)
+    stmt = filter_stmt(stmt, sql_table, **matching)
+    with engine.connect() as conn:
+        conn.execute(stmt)
+        conn.commit()
+
 def get_from_sql(return_class, stmt, engine):
     """
     Get all items from table as per SQL statement
@@ -118,6 +134,7 @@ class FilterOperator():
     """
 
     def __init__(self, name, meta):
+        self.__name = name
         if name in meta.tables:
             self.__sql_table = meta.tables[name]
         else:
@@ -157,6 +174,9 @@ class FilterOperator():
 
     def __getattr__(self, name):
         if getattr(self.__sql_table, "name", False):
-            self.__column = getattr(self.__sql_table.c, name)
+            self.__column = getattr(self.__sql_table.c, name, False)
+            if self.__column is False:
+                msg = f"'{self.__name}' does not hold '{name}'"
+                raise GeneralMemoryError(msg)
             self.__operator = True
         return self
